export function timeFix () {
  const time = new Date()
  const hour = time.getHours()
  return hour < 9 ? '早上好' : hour <= 11 ? '上午好' : hour <= 13 ? '中午好' : hour < 20 ? '下午好' : '晚上好'
}

export function welcome () {
  const arr = ['休息一会儿吧', '准备吃什么呢?', '要不要打一把 DOTA', '我猜你可能累了']
  const index = Math.floor(Math.random() * arr.length)
  return arr[index]
}

/**
 * 触发 window.resize
 */
export function triggerWindowResizeEvent () {
  const event = document.createEvent('HTMLEvents')
  event.initEvent('resize', true, true)
  event.eventType = 'message'
  window.dispatchEvent(event)
}

export function handleScrollHeader (callback) {
  let timer = 0

  let beforeScrollTop = window.pageYOffset
  callback = callback || function () {}
  window.addEventListener(
    'scroll',
    event => {
      clearTimeout(timer)
      timer = setTimeout(() => {
        let direction = 'up'
        const afterScrollTop = window.pageYOffset
        const delta = afterScrollTop - beforeScrollTop
        if (delta === 0) {
          return false
        }
        direction = delta > 0 ? 'down' : 'up'
        callback(direction)
        beforeScrollTop = afterScrollTop
      }, 50)
    },
    false
  )
}

/**
 * Remove loading animate
 * @param id parent element id or class
 * @param timeout
 */
export function removeLoadingAnimate (id = '', timeout = 1500) {
  if (id === '') {
    return
  }
  setTimeout(() => {
    document.body.removeChild(document.getElementById(id))
  }, timeout)
}

/**
 * @param {String|Number} value 要验证的字符串或数值
 * @param {*} validList 用来验证的列表
 */
export function oneOf (value, validList) {
  for (let i = 0; i < validList.length; i++) {
    if (value === validList[i]) {
      return true
    }
  }
  return false
}
// 树查找
export function treeFind (tree, func) {
  for (const data of tree) {
    if (func(data)) return data
    if (data.children) {
      const res = treeFind(data.children, func)
      if (res) return res
    }
  }
  return null
}
// 是否有价格权限
export function hasPriceAuth(authNode, priceOptions){
  const codes = []
  const ret = []
  // 过滤当前节点下的非价格权限菜单
  authNode.map(item=>{
    const a = item.code.split('_')
    const hasCode = priceOptions.find(k => k.value == a[a.length-1])
    if(hasCode){
      codes.push(a[a.length-1])
    }
  })
  // 生成权限参数
  priceOptions.map(item => {
    ret.push(codes.includes(item.value)?1:0)
  })
  return ret
}
// 获取接口对应的价格权限code
export function getAuthPriceCode (config, router, store) {
  const permission = router.history.current.meta.permission
  const curActionPermission = store.state.app.curActionPermission
  const priceOptions = store.state.app.priceAuthOptions
  const authCode = curActionPermission || permission
  console.log(authCode)
  if(authCode){
    const url = config.url
    const authTree = store.state.app.authMenusList
    const authNode = treeFind(authTree,(item)=>item.code == authCode)
    console.log(authNode)
    const hasReqUrl = authNode.permission.split(',').find(item => url.replace(/\//g,'_').indexOf(item)>=0)
    
    if(hasReqUrl&&authNode.children&&authNode.children.length){
      return hasPriceAuth(authNode.children,priceOptions)
    }
    return []
  }
  return []
}